@@ -4,14 +4,14 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 #ifndef UMLATTRIBUTEDIALOG_H
 #define UMLATTRIBUTEDIALOG_H
 
-#include <kdialog.h>
+#include "singlepagedialogbase.h"
 
 class DocumentationWidget;
 class QCheckBox;
@@ -19,14 +19,16 @@ class QGroupBox;
 class QRadioButton;
 class QLabel;
 class UMLAttribute;
-class KComboBox;
 class KLineEdit;
+class UMLDatatypeWidget;
+class UMLStereotypeWidget;
+class VisibilityEnumWidget;
 
 /**
  * @author Paul Hensgen
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
-class UMLAttributeDialog : public KDialog
+class UMLAttributeDialog : public SinglePageDialogBase
 {
     Q_OBJECT
 public:
@@ -34,13 +36,9 @@ public:
     ~UMLAttributeDialog();
 
 protected:
-
     void setupDialog();
-
     bool apply();
 
-    void insertTypesSorted(const QString& type = QString());
-
     /**
      *   The Attribute to represent
      */
@@ -48,19 +46,15 @@ protected:
 
     //GUI Widgets
     QGroupBox * m_pValuesGB;
-    QGroupBox * m_pScopeGB;
-    QRadioButton * m_pPublicRB, * m_pPrivateRB,  * m_pProtectedRB, * m_pImplementationRB;
-    QLabel * m_pTypeL, * m_pNameL, * m_pInitialL, * m_pStereoTypeL;
-    KComboBox * m_pTypeCB;
-    KLineEdit * m_pNameLE, * m_pInitialLE, * m_pStereoTypeLE;
+    QLabel * m_pNameL, * m_pInitialL;
+    KLineEdit * m_pNameLE, * m_pInitialLE;
     QCheckBox* m_pStaticCB;
+    UMLDatatypeWidget *m_datatypeWidget;
+    UMLStereotypeWidget *m_stereotypeWidget;
+    VisibilityEnumWidget *m_visibilityEnumWidget;
     DocumentationWidget *m_docWidget;
 
 public slots:
-
-    void slotApply();
-
-    void slotOk();
     void slotNameChanged(const QString &);
 };
 
